==> gbsite-1.1.0.tar.gz: gbsite/htdocs/info/ml.php <==
<?
    $web_page = "mktginfopage";
    include("site_info.php");
    $group_group_id = "genpage";

    if(empty($first_name)) $context_error[] = "You must fill in your first name.";
    if(empty($last_name)) $context_error[] = "You must fill in your last name.";
    if(empty($email)) $context_error[] = "You must fill in your email address.";

    if(!empty($context_error)) {
        $web_page = "contextpage";
        $context = "Error submitting data:";
    } else {
        if(empty($first_name)) {
            $context_error[] = "You must enter your first name.";
        }
        if(empty($last_name)) {
            $context_error[] = "You must enter your last name.";
        }
        if(!empty($email)) {
            if(!eregi("^[_\.0-9a-z-]+@([0-9a-z][-0-9a-z\.]+)\.([a-z]{2,3}$)", $email, $check)) {
                $context_error[] = "The email address you entered does not appear to be valid.";
            }
        } else {
            $context_errorp[] = "You must enter an email address.";
        }

        $id         = sqlText(md5(time()));
        $mktg_code  = sqlText($mktg_code);
        $first_name = sqlText($first_name);
        $last_name  = sqlText($last_name);
        $email      = sqlText($email);
        $company    = sqlText($company);
        $address    = sqlText($address);
        $city       = sqlText($city);
        $state      = sqlText($state);
        $zip        = sqlText($zip);
        $country    = sqlText($country);


        if(empty($context_error)) {
            if($mktg_code == "null") $mktg_code = "'unknown'";
            $query = "insert into mktg_contact ".
                     "values ($id, $email, $mktg_code, $first_name, ".
                     "        $last_name, $company, $address, $city, ".
                     "        $state, $zip, $country) ";
            $res   = @pg_exec($conn,$query);
            if(!empty($res)) {
                $mktg_contact = $id;
                setcookie("mktg_contact",$id,time()+31536000,"/");
        
                $operating_system = sqlText($operating_system);
                $job_function     = sqlText($job_function);
                $activity         = sqlText($activity);
                $size             = sqlText($size);
                if(empty($postgres_user)) $postgres_user = "null";
                if(empty($newsletter)) $newsletter = "null";
                if(empty($mail_CD)) $mail_CD = "null";
                if(empty($contact_me)) $contact_me = "null";
                $comment          = sqlText($comment);
        
                $query = "insert into mktg_response ".
                         "values ($id, $operating_system, $job_function, ".
                         "        $activity, $size, $postgres_user, ".
                         "        $newsletter, $mail_CD, $comment, $contact_me) ";
                $res   = @pg_exec($conn,$query);
        
                if(!empty($send_to)) {
                    RedirectTo($send_to);
                    exit();
                } else {
                    $web_page = "documententrypage";
                    $context = "Thank you for your submission.";
                    
                }
            } else { 
                $web_page = "documententrypage";
                $context = "Thank you!";
            }
        } else {
            $web_page = "contextpage";
            $context = "There were errors processing your submission.";
        }
    }

    include($page_template);
 ?>

==> gbsite-2.0.0.tar.gz: gbsite/htdocs/info/ml.php <==
<?
    $web_page = "mktginfopage";
    include("site_info.php");
    $group_group_id = "genpage";

    if(empty($first_name)) $context_error[] = "You must fill in your first name.";
    if(empty($last_name)) $context_error[] = "You must fill in your last name.";
    if(empty($email)) $context_error[] = "You must fill in your email address.";

    if(!empty($context_error)) {
        $web_page = "contextpage";
        $context = "Error submitting data:";
    } else {
        if(!empty($email)) {
            if(!eregi("^[_\.0-9a-z+-]+@([0-9a-z][-0-9a-z\.]+)\.([a-z]{2,3}$)", $email, $check)) {
                $context_error[] = "The email address you entered does not appear to be valid.";
            }
        } else {
            $context_error[] = "You must enter an email address.";
        }

        $id         = sqlText(md5(time()));
        $mktg_code  = sqlText($mktg_code);
        $first_name = sqlText($first_name);
        $last_name  = sqlText($last_name);
        $email      = sqlText($email);
        $company    = sqlText($company);
        $address    = sqlText($address);
        $city       = sqlText($city);
        $state      = sqlText($state);
        $zip        = sqlText($zip);
        $country    = sqlText($country);


        if(empty($context_error)) {
            if($mktg_code == "null") $mktg_code = "'unknown'";
            $query = "insert into mktg_contact ".
                     "values ($id, $email, $mktg_code, $first_name, ".
                     "        $last_name, $company, $address, $city, ".
                     "        $state, $zip, $country) ";
            $res   = @pg_exec($conn,$query);
            $mktg_contact = $id;
            setcookie("mktg_contact",$id,time()+31536000,"/");
            if(!empty($res)) {
        
                $operating_system = sqlText($operating_system);
                $job_function     = sqlText($job_function);
                $activity         = sqlText($activity);
                $size             = sqlText($size);
                if(empty($postgres_user)) $postgres_user = "null";
                if(empty($newsletter)) $newsletter = "null";
                if(empty($mail_CD)) $mail_CD = "null";
                if(empty($contact_me)) $contact_me = "null";
                $comment          = sqlText($comment);
        
                $query = "insert into mktg_response ".
                         "values ($id, $operating_system, $job_function, ".
                         "        $activity, $size, $postgres_user, ".
                         "        $newsletter, $mail_CD, $comment, $contact_me) ";
                $res   = @pg_exec($conn,$query);
            } 
            if(!empty($send_to)) {
                RedirectTo($send_to);
                exit();
            }
            $web_page = "documententrypage";
            $context = "Thank you for your submission.";
        } else {
            $web_page = "contextpage";
            $context = "There were errors processing your submission.";
        }
    }

    include($page_template);
 ?>
